You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@kylin.apache.org by li...@apache.org on 2015/03/14 01:00:38 UTC

[03/50] [abbrv] incubator-kylin git commit: smaller region size

smaller region size


Project: http://git-wip-us.apache.org/repos/asf/incubator-kylin/repo
Commit: http://git-wip-us.apache.org/repos/asf/incubator-kylin/commit/37f9a735
Tree: http://git-wip-us.apache.org/repos/asf/incubator-kylin/tree/37f9a735
Diff: http://git-wip-us.apache.org/repos/asf/incubator-kylin/diff/37f9a735

Branch: refs/heads/streaming-localdict
Commit: 37f9a735cd8d5ca27b208182117d844c85bf1c70
Parents: 6a91c5c
Author: Li, Yang <ya...@ebay.com>
Authored: Tue Mar 10 16:56:27 2015 +0800
Committer: Li, Yang <ya...@ebay.com>
Committed: Tue Mar 10 16:56:27 2015 +0800

----------------------------------------------------------------------
 .../kylin/job/hadoop/cube/RangeKeyDistributionReducer.java   | 8 ++++----
 1 file changed, 4 insertions(+), 4 deletions(-)
----------------------------------------------------------------------


http://git-wip-us.apache.org/repos/asf/incubator-kylin/blob/37f9a735/job/src/main/java/org/apache/kylin/job/hadoop/cube/RangeKeyDistributionReducer.java
----------------------------------------------------------------------
diff --git a/job/src/main/java/org/apache/kylin/job/hadoop/cube/RangeKeyDistributionReducer.java b/job/src/main/java/org/apache/kylin/job/hadoop/cube/RangeKeyDistributionReducer.java
index 6bdacfd..6da179c 100644
--- a/job/src/main/java/org/apache/kylin/job/hadoop/cube/RangeKeyDistributionReducer.java
+++ b/job/src/main/java/org/apache/kylin/job/hadoop/cube/RangeKeyDistributionReducer.java
@@ -39,11 +39,11 @@ import org.apache.kylin.job.constant.BatchConstants;
 public class RangeKeyDistributionReducer extends KylinReducer<Text, LongWritable, Text, LongWritable> {
 
     public static final long ONE_GIGA_BYTES = 1024L * 1024L * 1024L;
-    public static final int SMALL_CUT = 10;  //  10 GB per region
-    public static final int MEDIUM_CUT = 20; //  20 GB per region
-    public static final int LARGE_CUT = 100; // 100 GB per region
+    public static final int SMALL_CUT = 5;  //  5 GB per region
+    public static final int MEDIUM_CUT = 10; //  10 GB per region
+    public static final int LARGE_CUT = 50; // 50 GB per region
     
-    public static final int MAX_REGION = 500;
+    public static final int MAX_REGION = 1000;
 
     private static final Logger logger = LoggerFactory.getLogger(RangeKeyDistributionReducer.class);